# How Does This Thing Work?

## One Word Explanation

Math.

## One Sentence Explanation (Layman Edition)

A good deal of math and computer science,
a handful of software engineering and
some optimization tricks.

## One Sentence Explanation (Pro Edition)

Using the Sakoe-Chiba Band Dynamic Time Warping (DTW) algorithm
to align the Mel-frequency cepstral coefficients (MFCCs)
representation of the given (real) audio wave and
the audio wave obtained by synthesizing the text fragments
with a TTS engine, eventually mapping
the computed alignment back onto the (real) time domain.

## Extended Explanation

To be written. Eventually. Some day.
